@@ -9,8 +9,8 @@ from .jsj import JSJ
 from .bailey import Bailey 
 from .ugroup import UniversityGroup
 from .roland import Roland 
-from .appfolio import AppFolio 
-from .american_campus import AmericanCampus 
+from .appfolio import * 
+from .american_campus import * 
 
 
 Individual = [
