@@ -1,10 +1,10 @@
 import requests
-from uiuc_apartments.shared import BaseAgency, Apartment
+from uiuc_apartments.shared import AgencyBase, Apartment
 import json
 
-class Smile(BaseAgency):
+class Smile(AgencyBase):
     url = 'https://www.smilestudentliving.com/_dm/s/rt/actions/sites/24eaedf2/collections/appfolio-listings/ENGLISH'
-    agency = "Smile"
+    name = "Smile"
 
     def get_all(self):
         apartments = []
@@ -28,6 +28,6 @@ class Smile(BaseAgency):
             link = "https://www.smilestudentliving.com/listings/detail/" + \
                 apartment['page_item_url']
             apartments.append(Apartment(address, market_rent, bedrooms,
-                                        bathrooms, link, available_date, self.agency, is_studio))
+                                        bathrooms, link, available_date, self.name, is_studio))
 
         return apartments
\ No newline at end of file
