@@ -13,11 +13,15 @@ class Apartment:
         self.is_studio = is_studio
 
     def __str__(self):
-        return f"'{self.address}' -- ${self.rent} {self.bedrooms}BED/{self.bathrooms}BATH {self.available_date} {self.link}"
+        info = 'Studio' if self.is_studio else f'{self.bedrooms} beds/{self.bathrooms} baths'
+        return f"<Apartment ${self.rent}/month {info} {self.available_date} {self.agency}>"
     __repr__ = __str__
 
 
-class BaseAgency(ABC):
+class AgencyBase(ABC):
+    name: str
+    url: str
+
     @abstractmethod
     def get_all(self):
         pass
